# Top-level functions

::: geoarrow.rust.core
    options:
      filters:
        - "!^_"
      members:
        - area
        - signed_area
        - center
        - centroid
        - chaikin_smoothing
        - chamberlain_duquette_unsigned_area
        - chamberlain_duquette_signed_area
        - convex_hull
        - densify
        - envelope
        - is_empty
        - geodesic_area_signed
        - geodesic_area_unsigned
        - geodesic_perimeter
        - simplify
        - simplify_vw
